﻿<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="xml" encoding="UTF-8" indent="yes" />

<xsl:template match="/">
	<xsl:apply-templates select="mulka/export"/>
</xsl:template>

<xsl:template match="export">
	<mulka version="2.00" type="application/mulka+xml">
		<print device="{$param-printer}">
			<paper name="A4" orientation="portrate" width="210" height="297" rows="1" collapse="never" />
			<margin top="10" left="10" right="10" bottom="10" />
			<xsl:apply-templates select="/mulka/export/competitors/competitor[@object-id=$param-competitor]"/>
		</print>
	</mulka>
</xsl:template>

<xsl:template match="competitor">

	<xsl:variable name="select-class">
		<xsl:value-of select="class/@object-id" />
	</xsl:variable>
	<xsl:variable name="select-course">
		<xsl:value-of select="course/@object-id" />
	</xsl:variable>

	<!-- 用紙ヘッダ -->
	<static>
		<area target="all" top="5" left="10" height="10" width="190" />
		<text top="2" left="2" font-face="ＭＳ Ｐゴシック" font-size="15">
			お疲れ様でした　暫定記録をお知らせします
		</text>
		<text top="2" left="188" font-face="ＭＳ Ｐゴシック" font-size="15" align="right">
			<xsl:value-of select="/mulka/export/event/name" />
		</text>
		<border x1="0" y1="10" x2="190" y2="10" border-width="0.4" />
	</static>

	<!-- 競技者ヘッダ -->
	<static>
		<area target="all" top="18" left="12" height="33" width="70" />

		<!-- クラス・スタートナンバー・Ｅカード番号 -->
		<text top="0" left="0" width="70" overflow="none" font-face="ＭＳ Ｐゴシック" font-size="12">
			<xsl:value-of select="/mulka/export/classes/class[@object-id=$param-class]/name" />
			<xsl:text>&#32;</xsl:text>
			<xsl:text>&#32;(</xsl:text>
			<xsl:value-of select="start-number" />
			<xsl:text>)&#32;&lt;</xsl:text>
			<xsl:value-of select="card/number" />
			<xsl:text>&gt;</xsl:text>
		</text>

		<!-- 氏名 -->
		<text top="5" left="0" width="70" overflow="hidden" font-face="ＭＳ Ｐゴシック" font-size="21">
			<xsl:value-of select="name" />
		</text>

		<!-- 所属 -->
		<text top="13" left="0" width="70" overflow="hidden" font-face="ＭＳ Ｐゴシック" font-size="12">
			<xsl:value-of select="club" />
		</text>

		<!-- 記録 -->
		<text top="20" left="0" font-face="ＭＳ Ｐゴシック" font-size="15">
			記録
		</text>
		<text top="20" left="15" font-face="ＭＳ Ｐゴシック" font-size="15">
			<xsl:value-of select="result" />
		</text>

		<!-- 順位 -->
		<text top="26" left="0" font-face="ＭＳ Ｐゴシック" font-size="12">
			<xsl:choose>
				<xsl:when test="status/@type = 'rank fixed'">
					<xsl:text>順位&#32;&#32;</xsl:text>
					<xsl:value-of select="class/@rank" />
					<xsl:text>位&#32;（確定）</xsl:text>
				</xsl:when>
				<xsl:when test="status/@type = 'finished'">
					<xsl:text>現在&#32;&#32;</xsl:text>
					<xsl:value-of select="class/@rank" />
					<xsl:text>位</xsl:text>
				</xsl:when>
				<xsl:when test="status/@type = 'percent over'">
					<xsl:text>（規定時間オーバー）</xsl:text>
				</xsl:when>
				<xsl:when test="status/@type = 'time over'">
					<xsl:text>（競技時間オーバー）</xsl:text>
				</xsl:when>
				<xsl:when test="status/@type = 'not compete'">
					<xsl:text>（参考記録）</xsl:text>
				</xsl:when>
			</xsl:choose>
		</text>
	</static>

	<!-- ラップタイム -->
	<flow>
		<area target="all" top="51" left="10" height="134" width="70" />
		<list collapse="always" flow-type="single-page">
			<list-head height="0" />
			<list-foot height="3" />
			<column-head height="0" />
			<column-foot height="0" />
			<lines>
				<!-- ヘッダ -->
				<line height="4">
					<text top="0" left="2" font-face="ＭＳ Ｐゴシック" font-size="9">
						ラップタイム一覧
					</text>
					<text top="0" left="0" width="70" align="right" font-face="ＭＳ Ｐゴシック" font-size="9">
						<xsl:text>（コース：</xsl:text>
						<xsl:value-of select="/mulka/export/courses/course[@object-id=$param-course]/name" />
						<xsl:text>）</xsl:text>
					</text>
				</line>

				<line height="4">

					<!-- トップ -->
					<text top="0" left="15" height="4" valign="middle"
						font-face="ＭＳ Ｐゴシック" font-size="7">
						トップラップ
					</text>

					<!-- 個人ラップ -->
					<text top="0" left="34" height="4" width="10" valign="middle" align="right" 
						font-face="ＭＳ Ｐゴシック" font-size="7">
						ラップ
					</text>
					<text top="0" left="44" height="4" width="6" valign="middle" align="right" 
						font-face="ＭＳ Ｐゴシック" font-size="7">
						順位
					</text>

					<!-- 個人積算 -->
					<text top="0" left="51" height="4" width="12" valign="middle" align="right" 
						font-face="ＭＳ Ｐゴシック" font-size="7">
						積算
					</text>
					<text top="0" left="63" height="4" width="6" valign="middle" align="right" 
						font-face="ＭＳ Ｐゴシック" font-size="7">
						順位
					</text>
					<border x1="2" x2="70" y1="4" y2="4" border-width="0.1" />
				</line>

				<!-- ラップ -->
				<xsl:apply-templates select="/mulka/export/analyzed-data/leg" />

			</lines>
		</list>
	</flow>

	<!-- 左右境界線・上下境界線 -->
	<static>
		<area target="all" top="15" left="10" height="160" width="190" />
		<border x1="75" y1="0" x2="75" y2="160" border-width="0.4" />
		<border x1="0" y1="160" x2="190" y2="160" border-width="0.4" />
	</static>

	<xsl:choose>
		<xsl:when test="status/@type = 'disqualify'">

			<!-- ペナチェックヘッダ -->
			<static>
				<area target="all" top="20" left="162" height="20" width="38" />
				<text top="0" left="0" width="20" height="5" align="left" valign="top" 
					font-face="ＭＳ Ｐゴシック" font-size="9">
					<xsl:text>コース</xsl:text>
				</text>
				<text top="0" left="20" width="18" height="5" align="right" valign="top" 
					font-face="ＭＳ Ｐゴシック" font-size="9">
					<xsl:value-of select="/mulka/export/courses/course[@object-id=$select-course]/name" />
				</text>
				<text top="5" left="0" width="20" height="5" align="left" valign="top" 
					font-face="ＭＳ Ｐゴシック" font-size="9">
					<xsl:text>スタート</xsl:text>
				</text>
				<text top="5" left="20" width="18" height="5" align="right" valign="top" 
					font-face="ＭＳ Ｐゴシック" font-size="9">
					<xsl:value-of select="start-time" />
				</text>
				<text top="10" left="0" width="20" height="5" align="left" valign="top" 
					font-face="ＭＳ Ｐゴシック" font-size="9">
					<xsl:text>フィニッシュ</xsl:text>
				</text>
				<text top="10" left="20" width="18" height="5" align="right" valign="top" 
					font-face="ＭＳ Ｐゴシック" font-size="9">
					<xsl:value-of select="finish-time" />
				</text>
				<text top="15" left="0" width="20" height="5" align="left" valign="top" 
					font-face="ＭＳ Ｐゴシック" font-size="9">
					<xsl:text>記録</xsl:text>
				</text>
				<text top="15" left="20" width="18" height="5" align="right" valign="top" 
					font-face="ＭＳ Ｐゴシック" font-size="9">
					<xsl:value-of select="result" />
				</text>

			</static>

			<!-- ラベルイメージ -->
			<static>
				<area target="all" top="40" left="147" height="120" width="55" />

				<xsl:call-template name="base">
					<xsl:with-param name="code">1</xsl:with-param>
				</xsl:call-template>

				<xsl:for-each select="card/punches/punch">
					<xsl:call-template name="mark">
						<xsl:with-param name="index"></xsl:with-param>
						<xsl:with-param name="code"><xsl:value-of select="number(@code)" /></xsl:with-param>
					</xsl:call-template>
				</xsl:for-each>

				<xsl:apply-templates select="/mulka/export/courses/course[@object-id=$select-course]" />
			</static>

			<!-- ペナチェック詳細 -->
			<flow>
				<area target="all" top="20" left="90" height="170" width="68" />

				<!-- 日本語説明 -->
				<xsl:if test="disq-info != ''">
					<list collapse="always">
						<list-head height="0" />
						<list-foot height="3" />
						<column-head height="0" />
						<column-foot height="0" />
						<lines>
							<line height="5">
								<text top="0" left="0" width="68" height="5" 
									align="left" valign="top" overflow="new-line"
									font-face="ＭＳ Ｐゴシック" font-size="9">
									<xsl:value-of select="disq-info" />
								</text>
							</line>
						</lines>
					</list>
				</xsl:if>

				<!-- 詳細通過情報 -->
				<list collapse="always" flow-type="single-page">
					<list-head height="0" />
					<list-foot height="0" />
					<column-head height="0" />
					<column-foot height="0" />
					<lines>
						<xsl:apply-templates select="check-detail-list/check-detail" />
					</lines>
				</list>
			</flow>

		</xsl:when>
		<xsl:otherwise>
			<static>
				<area target="all" top="95" left="95" height="20" width="90" />
				<text top="0" left="0" width="100" align="center"
					font-face="ＭＳ Ｐゴシック" font-size="15">
					<xsl:text>全コントロールの通過が確認されました</xsl:text>
				</text>
			</static>
		</xsl:otherwise>
	</xsl:choose>

	<!-- 成績一覧 -->
	<static>
		<area target="all" top="178" left="10" height="6" width="190" />
		<xsl:apply-templates select="/mulka/export/classes/class[@object-id=$select-class]" mode="head"/>
	</static>
	<flow>
		<area target="all" top="184" left="10" height="100" width="190" cols="3" col-margin="5" />
		<xsl:apply-templates select="/mulka/export/classes/class[@object-id=$select-class]" mode="body"/>
	</flow>

	<!-- 下側境界線 -->
	<static>
		<area target="all" top="184" left="10" height="103" width="190" />
		<border x1="62.5" y1="0" x2="62.5" y2="100" border-width="0.3" />
		<border x1="127.5" y1="0" x2="127.5" y2="100" border-width="0.3" />
		<border x1="0" y1="103" x2="190" y2="103" border-width="0.4" />
	</static>

</xsl:template>

<!-- ラップタイム一覧：各行 -->
<xsl:template match="leg">
	<line height="4">
		<!-- n→n+1 -->
		<text top="0" left="2" height="4" width="4" valign="bottom" align="right" 
			font-face="ＭＳ Ｐゴシック" font-size="8">
			<xsl:choose>
				<xsl:when test="@index = 1">
					<xsl:text>△</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="@index - 1" />
				</xsl:otherwise>
			</xsl:choose>
		</text>
		<text top="0" left="5" height="4" width="4" valign="bottom" align="right" 
			font-face="ＭＳ Ｐゴシック" font-size="8">
			<xsl:text>→</xsl:text>
		</text>
		<text top="0" left="8" height="4" width="4" valign="bottom" align="right" 
			font-face="ＭＳ Ｐゴシック" font-size="8">
			<xsl:choose>
				<xsl:when test="position() = last()">
					<xsl:text>F</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="@index" />
				</xsl:otherwise>
			</xsl:choose>
		</text>

		<separator position="13" border-width="0.2" />

		<!-- トップ氏名 -->
		<text top="0" left="15" height="4" width="10" valign="bottom" align="left" overflow="hidden" space="delete"
			font-face="ＭＳ Ｐ明朝" font-size="8">
			<xsl:variable name="top-competitor">
				<xsl:value-of select="top/@object-id" />
			</xsl:variable>
			<xsl:value-of select="/mulka/export/competitors-name/competitor[@object-id=$top-competitor]/@name" />
		</text>

		<!-- トップラップ -->
		<text top="0" left="25" height="4" width="8" valign="bottom" align="right" 
			font-face="ＭＳ Ｐ明朝" font-size="8">
			<xsl:value-of select="top/@lap-time" />
		</text>

		<separator position="34" border-width="0.2" />

		<!-- 個人ラップ -->
		<text top="0" left="34" height="4" width="10" valign="bottom" align="right" 
			font-face="ＭＳ Ｐゴシック" font-size="8">
			<xsl:value-of select="own/@lap-time" />
		</text>
		<text top="0" left="44" height="4" width="6" valign="bottom" align="right" 
			font-face="ＭＳ Ｐゴシック" font-size="8">
			<xsl:value-of select="own/@lap-rank" />
		</text>

		<!-- 個人積算 -->
		<text top="0" left="51" height="4" width="12" valign="bottom" align="right" 
			font-face="ＭＳ Ｐ明朝" font-size="8">
			<xsl:value-of select="own/@elapse-time" />
		</text>
		<text top="0" left="63" height="4" width="6" valign="bottom" align="right" 
			font-face="ＭＳ Ｐ明朝" font-size="8">
			<xsl:value-of select="own/@elapse-rank" />
		</text>

		<border x1="2" x2="70" y1="4" y2="4" border-width="0.2" />

	</line>
</xsl:template>

<!-- バックアップラベル用 -->
<xsl:template match="course">
	<xsl:apply-templates select="controls/control/unit"/>
</xsl:template>

<xsl:template match="unit">
	<xsl:call-template name="mark">
		<xsl:with-param name="index"><xsl:value-of select="../@index" /></xsl:with-param>
		<xsl:with-param name="code"><xsl:value-of select="number(.)" /></xsl:with-param>
	</xsl:call-template>
</xsl:template>

<xsl:template name="base">
	<xsl:param name="code" />
	<xsl:call-template name="mark">
		<xsl:with-param name="index">・</xsl:with-param>
		<xsl:with-param name="code"><xsl:value-of select="$code" /></xsl:with-param>
	</xsl:call-template>
	<xsl:if test="$code != 176">
		<xsl:call-template name="base">
			<xsl:with-param name="code"><xsl:value-of select="$code + 1" /></xsl:with-param>
		</xsl:call-template>
	</xsl:if>
</xsl:template>

<xsl:template name="draw">
	<xsl:param name="x" />
	<xsl:param name="y" />
	<xsl:param name="index" />
	<xsl:choose>
		<xsl:when test="$index = ''">
			<text top="{$y * 4 + 2}" left="{55 - $x * 4 + 2}" valign="middle" align="center"
				 font-face="ＭＳ Ｐゴシック" font-size="12" fore-color="#cccccc">
				<xsl:text>●</xsl:text>
			</text>
		</xsl:when>
		<xsl:when test="$index = '・'">
			<text top="{$y * 4 + 2}" left="{55 - $x * 4 + 2}" valign="middle" align="center"
				 font-face="ＭＳ Ｐゴシック" font-size="9" fore-color="#cccccc">
				<xsl:text>・</xsl:text>
			</text>
		</xsl:when>
		<xsl:otherwise>
			<text top="{$y * 4 + 2}" left="{55 - $x * 4 + 2}" valign="middle" align="center"
				 font-face="ＭＳ Ｐゴシック" font-size="9">
				<xsl:value-of select="$index" />
			</text>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="mark">
	<xsl:param name="code" />
	<xsl:param name="index" />
	<xsl:choose>
		<xsl:when test="$code &gt;= 31 and $code &lt;= 38">
			<xsl:call-template name="draw">
				<xsl:with-param name="index"><xsl:value-of select="$index" /></xsl:with-param>
				<xsl:with-param name="x"><xsl:value-of select="$code - 29" /></xsl:with-param>
				<xsl:with-param name="y"><xsl:value-of select="1" /></xsl:with-param>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="$code &gt;= 39 and $code &lt;= 65">
			<xsl:call-template name="draw">
				<xsl:with-param name="index"><xsl:value-of select="$index" /></xsl:with-param>
				<xsl:with-param name="x"><xsl:value-of select="(($code - 9) mod 10) + 1" /></xsl:with-param>
				<xsl:with-param name="y"><xsl:value-of select="floor(($code - 19) div 10)" /></xsl:with-param>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="$code = 67">
			<xsl:call-template name="draw">
				<xsl:with-param name="index"><xsl:value-of select="$index" /></xsl:with-param>
				<xsl:with-param name="x"><xsl:value-of select="8" /></xsl:with-param>
				<xsl:with-param name="y"><xsl:value-of select="4" /></xsl:with-param>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="$code &gt;= 69 and $code &lt;= 84">
			<xsl:call-template name="draw">
				<xsl:with-param name="index"><xsl:value-of select="$index" /></xsl:with-param>
				<xsl:with-param name="x"><xsl:value-of select="(($code - 11) mod 10) + 1" /></xsl:with-param>
				<xsl:with-param name="y"><xsl:value-of select="floor(($code - 21) div 10)" /></xsl:with-param>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="$code = 85">
			<xsl:call-template name="draw">
				<xsl:with-param name="index"><xsl:value-of select="$index" /></xsl:with-param>
				<xsl:with-param name="x"><xsl:value-of select="7" /></xsl:with-param>
				<xsl:with-param name="y"><xsl:value-of select="6" /></xsl:with-param>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="$code &gt;= 87 and $code &lt;= 88">
			<xsl:call-template name="draw">
				<xsl:with-param name="index"><xsl:value-of select="$index" /></xsl:with-param>
				<xsl:with-param name="x"><xsl:value-of select="(($code - 10) mod 10) + 1" /></xsl:with-param>
				<xsl:with-param name="y"><xsl:value-of select="floor(($code - 20) div 10)" /></xsl:with-param>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="$code &gt;= 90 and $code &lt;= 94">
			<xsl:call-template name="draw">
				<xsl:with-param name="index"><xsl:value-of select="$index" /></xsl:with-param>
				<xsl:with-param name="x"><xsl:value-of select="(($code - 11) mod 10) + 1" /></xsl:with-param>
				<xsl:with-param name="y"><xsl:value-of select="floor(($code - 21) div 10)" /></xsl:with-param>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="$code &gt;= 95 and $code &lt;= 97">
			<xsl:call-template name="draw">
				<xsl:with-param name="index"><xsl:value-of select="$index" /></xsl:with-param>
				<xsl:with-param name="x"><xsl:value-of select="(($code - 9) mod 10) + 1" /></xsl:with-param>
				<xsl:with-param name="y"><xsl:value-of select="floor(($code - 19) div 10)" /></xsl:with-param>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="$code &gt;= 100 and $code &lt;= 104">
			<xsl:call-template name="draw">
				<xsl:with-param name="index"><xsl:value-of select="$index" /></xsl:with-param>
				<xsl:with-param name="x"><xsl:value-of select="(($code - 11) mod 10) + 1" /></xsl:with-param>
				<xsl:with-param name="y"><xsl:value-of select="floor(($code - 21) div 10)" /></xsl:with-param>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="$code &gt;= 105 and $code &lt;= 168">
			<xsl:call-template name="draw">
				<xsl:with-param name="index"><xsl:value-of select="$index" /></xsl:with-param>
				<xsl:with-param name="x"><xsl:value-of select="(($code - 9) mod 10) + 1" /></xsl:with-param>
				<xsl:with-param name="y"><xsl:value-of select="floor(($code - 19) div 10)" /></xsl:with-param>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="$code &gt;= 169 and $code &lt;= 176">
			<xsl:call-template name="draw">
				<xsl:with-param name="index"><xsl:value-of select="$index" /></xsl:with-param>
				<xsl:with-param name="x"><xsl:value-of select="(($code - 8) mod 10) + 1" /></xsl:with-param>
				<xsl:with-param name="y"><xsl:value-of select="floor(($code - 18) div 10)" /></xsl:with-param>
			</xsl:call-template>
		</xsl:when>

		<xsl:when test="$code &gt;= 177 and $code &lt;= 184">
			<xsl:call-template name="draw">
				<xsl:with-param name="index"><xsl:value-of select="$index" /></xsl:with-param>
				<xsl:with-param name="x"><xsl:value-of select="(($code - 111) mod 10) + 1" /></xsl:with-param>
				<xsl:with-param name="y"><xsl:value-of select="floor(($code - 121) div 10)" /></xsl:with-param>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="$code = 185">
			<xsl:call-template name="draw">
				<xsl:with-param name="index"><xsl:value-of select="$index" /></xsl:with-param>
				<xsl:with-param name="x"><xsl:value-of select="7" /></xsl:with-param>
				<xsl:with-param name="y"><xsl:value-of select="6" /></xsl:with-param>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="$code &gt;= 187 and $code &lt;= 188">
			<xsl:call-template name="draw">
				<xsl:with-param name="index"><xsl:value-of select="$index" /></xsl:with-param>
				<xsl:with-param name="x"><xsl:value-of select="(($code - 110) mod 10) + 1" /></xsl:with-param>
				<xsl:with-param name="y"><xsl:value-of select="floor(($code - 120) div 10)" /></xsl:with-param>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="$code &gt;= 190 and $code &lt;= 194">
			<xsl:call-template name="draw">
				<xsl:with-param name="index"><xsl:value-of select="$index" /></xsl:with-param>
				<xsl:with-param name="x"><xsl:value-of select="(($code - 111) mod 10) + 1" /></xsl:with-param>
				<xsl:with-param name="y"><xsl:value-of select="floor(($code - 121) div 10)" /></xsl:with-param>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="$code &gt;= 195 and $code &lt;= 197">
			<xsl:call-template name="draw">
				<xsl:with-param name="index"><xsl:value-of select="$index" /></xsl:with-param>
				<xsl:with-param name="x"><xsl:value-of select="(($code - 109) mod 10) + 1" /></xsl:with-param>
				<xsl:with-param name="y"><xsl:value-of select="floor(($code - 119) div 10)" /></xsl:with-param>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="$code &gt;= 200 and $code &lt;= 204">
			<xsl:call-template name="draw">
				<xsl:with-param name="index"><xsl:value-of select="$index" /></xsl:with-param>
				<xsl:with-param name="x"><xsl:value-of select="(($code - 111) mod 10) + 1" /></xsl:with-param>
				<xsl:with-param name="y"><xsl:value-of select="floor(($code - 121) div 10)" /></xsl:with-param>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="$code &gt;= 205 and $code &lt;= 249">
			<xsl:call-template name="draw">
				<xsl:with-param name="index"><xsl:value-of select="$index" /></xsl:with-param>
				<xsl:with-param name="x"><xsl:value-of select="(($code - 109) mod 10) + 1" /></xsl:with-param>
				<xsl:with-param name="y"><xsl:value-of select="floor(($code - 119) div 10)" /></xsl:with-param>
			</xsl:call-template>
		</xsl:when>

	</xsl:choose>

</xsl:template>

<!-- 通過情報用 -->
<xsl:template match="check-detail">
	<line height="4">
		<!-- 第nコントロール -->
		<text top="0" left="0" height="4" width="8" valign="bottom" align="right" 
			font-face="ＭＳ Ｐゴシック" font-size="8">
			<xsl:value-of select="@control-index" />
		</text>
		<!-- パンチした、または、パンチすべきコントロールコード -->
		<xsl:choose>
			<xsl:when test="@punch-unit-code != ''">
				<text top="0" left="8" height="4" width="16" valign="bottom" align="right" 
					font-face="ＭＳ Ｐ明朝" font-size="8">
					<xsl:text>(</xsl:text>
					<xsl:value-of select="@punch-unit-code" />
					<xsl:text>)</xsl:text>
				</text>
			</xsl:when>
			<xsl:when test="@control-unit-code != ''">
				<text top="0" left="8" height="4" width="16" valign="bottom" align="right" 
					font-face="ＭＳ Ｐ明朝" font-size="8">
					<xsl:text>(</xsl:text>
					<xsl:value-of select="@control-unit-code" />
					<xsl:text>)</xsl:text>
				</text>
			</xsl:when>
		</xsl:choose>
		<!-- ラップタイム -->
		<text top="0" left="24" height="4" width="14" valign="bottom" align="right" 
			font-face="ＭＳ Ｐ明朝" font-size="8">
			<xsl:value-of select="@lap-time" />
		</text>
		<!-- Ｅカード時計 -->
		<text top="0" left="38" height="4" width="14" valign="bottom" align="right" 
			font-face="ＭＳ Ｐ明朝" font-size="8">
			<xsl:value-of select="@check-time" />
		</text>
		<!-- 通過時刻 -->
		<text top="0" left="52" height="4" width="14" valign="bottom" align="right" 
			font-face="ＭＳ Ｐ明朝" font-size="8">
			<xsl:value-of select="@check-hour" />
		</text>
	</line>
</xsl:template>

<!-- 成績一覧用 -->
<xsl:template match="class" mode="head">
	<text top="0" left="2" font-face="ＭＳ Ｐゴシック" font-size="12">
		<xsl:value-of select="name" />
		<xsl:text>クラス&#32;成績一覧</xsl:text>
	</text>
	<text top="0" left="90" width="100" align="right" font-face="ＭＳ Ｐゴシック" font-size="7">
		<xsl:text>出走 </xsl:text>
		<xsl:value-of select="start-count" />
		<xsl:text> 、 </xsl:text>
		<xsl:text>未帰還 </xsl:text>
		<xsl:value-of select="not-finish-count" />
		<xsl:text> 、 </xsl:text>
		<xsl:choose>
			<xsl:when test="rank-fix-record-time/@type='normal'">
				<xsl:value-of select="rank-fix-record-time" />
				<xsl:text> まで順位確定</xsl:text>
			</xsl:when>
			<xsl:when test="rank-fix-record-time/@type='all'">
				<xsl:text>全員順位確定</xsl:text>
			</xsl:when>
			<xsl:otherwise>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:text> 、 </xsl:text>
		<xsl:text>$t現在</xsl:text>
	</text>
	<text top="0" left="70" width="100" align="left" font-face="ＭＳ Ｐゴシック" font-size="7">
		<xsl:text>各記録は暫定であり正式ではありません</xsl:text>
	</text>
</xsl:template>

<xsl:template match="class" mode="body">
	<xsl:if test="result-list/@count!='0'">
		<list collapse="never" flow-type="single-page">
			<list-head height="0" />
			<list-foot height="0" />
			<column-head height="0" />
			<column-foot height="0" />
			<lines>
				<xsl:apply-templates mode="result-list" select="result-list/competitor"/>
			</lines>
		</list>
	</xsl:if>
</xsl:template>

<xsl:template match="competitor" mode="result-list">
	<xsl:variable name="select-competitor"><xsl:value-of select="@object-id" /></xsl:variable>
	<xsl:apply-templates mode="result-name" select="/mulka/export/competitors-name/competitor[@object-id=$select-competitor]"/>

	<xsl:if test="@last-qualify-place='true'">
		<line height="15">
			<text top="0" left="0" height="15" width="190" valign="bottom" align="center" font-face="ＭＳ Ｐゴシック" font-size="24">
				<xsl:text>ここまで通過</xsl:text>
			</text>
			<border border-width="0.8" x1="10" x2="70" y1="10" y2="10"/>
			<border border-width="0.8" x1="120" x2="180" y1="10" y2="10"/>
		</line>
	</xsl:if>

</xsl:template>

<xsl:template match="competitor" mode="result-name">
	<line height="11">
		<text top="0" left="8" height="11" width="7" valign="bottom" align="center" font-face="ＭＳ Ｐ明朝" font-size="24">
			<xsl:choose>
				<xsl:when test="@status='rank fixed'">
					<xsl:text>・</xsl:text>
				</xsl:when>
				<xsl:when test="@status='disqualify'">
					<xsl:text>×</xsl:text>
				</xsl:when>
				<xsl:when test="@status='time over'">
					<xsl:text>×</xsl:text>
				</xsl:when>
				<xsl:when test="@status='percent over'">
					<xsl:text>×</xsl:text>
				</xsl:when>
				<xsl:when test="@status='irregular'">
					<xsl:text>？</xsl:text>
				</xsl:when>
			</xsl:choose>
		</text>
		<text top="0" left="15" height="11" width="10" valign="bottom" align="right" font-face="ＭＳ Ｐ明朝" font-size="24">
			<xsl:value-of select="@class-rank" />
		</text>
		<text top="0" left="30" height="11" width="57" overflow="hidden" valign="bottom" align="left" font-face="ＭＳ Ｐ明朝" font-size="24">
			<xsl:value-of select="@name" />
		</text>
		<text top="0" left="90" height="11" width="30" valign="bottom" align="right" font-face="ＭＳ Ｐ明朝" font-size="24">
			<xsl:value-of select="@result" />
		</text>
		<text top="0" left="125" height="11" width="65" overflow="hidden" valign="bottom" align="left" font-face="ＭＳ Ｐ明朝" font-size="24">
			<xsl:value-of select="@club" />
		</text>
		<xsl:if test="@object-id = $param-competitor">
			<border x1="2" y1="11" x2="190" y2="11" border-width="0.3" />
		</xsl:if>
	</line>

</xsl:template>

</xsl:stylesheet>

